# snowbim
This is to do something awesome between snowflake database and tabular model file (.bim).

Those are:
* Refresh tables (key: name)
* Refresh table's columns (key: name)
* Refresh table's partitions (key: name)

Supported Models:
* Compatibility Level: 1550
* Default Power BI Data Source Version: powerBI_V3


Virtual enviroment:
```
python -m venv env
```

Activate virtual env:
```
Windows: 	.\env\Scripts\activate
Linux:		source env/bin/activate
```

Install dependencies:
```
pip install -r requirements.txt
```

